# DEFAULT_FILE_STORAGE = "storages.backends.s3boto3.S3Boto3Storage"
AWS_ACCESS_KEY_ID = "AKIASSAHM44JUOBILO2V"
AWS_SECRET_ACCESS_KEY = "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"
AWS_STORAGE_BUCKET_NAME = "artur-testing-1"
AWS_QUERYSTRING_AUTH = True



from flask import Flask, request, session
from flask_babelex import Babel
from flask_sqlalchemy import SQLAlchemy

app: Flask
db: SQLAlchemy

# app = Flask(__name__)
# app.config.from_pyfile('config.py')
# db = SQLAlchemy(app)


def create_app(config_filename: str) -> Flask:
    global app
    app = Flask(__name__)
    app.config.from_pyfile(config_filename)

    global db
    db = SQLAlchemy(app)

    return app


create_app("config.py")


# Initialize babel
babel = Babel(app)


@babel.localeselector
def get_locale():
    override = request.args.get("lang")

    if override:
        session["lang"] = override

    return session.get("lang", "en")


import faker_file_admin.main



import os

from setuptools import find_packages, setup

version = "0.9.1"

try:
    readme = open(os.path.join(os.path.dirname(__file__), "README.rst")).read()
except OSError:
    readme = ""

dependency_links = []

# Dependencies
install_requires = [
    "Faker",
]

tests_require = [
    "factory_boy",
    "parametrize",
    "pytest",
    "pytest-cov",
    "pytest-django",
    "pytest-pythonpath",
    "pytest-ordering",
    "coverage",
]

extras_require = (
    {
        "all": [
            "Faker",
            "imgkit",
            "odfpy",
            "openpyxl",
            "pathy[all]",
            "pdfkit",
            "python-docx",
            "python-pptx",
            "tablib",
        ],
        "django": ["Django>=2.2"],
        "docx": ["python-docx"],
        "images": ["imgkit"],
        "pdf": ["pdfkit"],
        "pptx": ["python-pptx"],
        "sqlalchemy": ["SQLAlchemy>=1.0", "SQLAlchemy-Utils>=0.37.0"],
        "xlsx": ["tablib", "openpyxl"],
        "ods": ["tablib", "odfpy"],
        "s3": ["pathy[s3]"],
        "gcs": ["pathy[gcs]"],
        "azure": ["pathy[azure]"],
    },
)

setup(
    name="faker-file",
    version=version,
    description="Generate fake files.",
    long_description=f"{readme}",
    long_description_content_type="text/x-rst",
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Environment :: Web Environment",
        "License :: OSI Approved :: MIT License",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Development Status :: 4 - Beta",
    ],
    project_urls={
        "Bug Tracker": "https://github.com/barseghyanartur/faker-file/issues",
        "Documentation": "https://faker-file.readthedocs.io/",
        "Source Code": "https://github.com/barseghyanartur/faker-file",
        "Changelog": "https://faker-file.readthedocs.io/"
        "en/latest/changelog.html",
    },
    keywords="faker, faker-file, files, testing, factories",
    author="Artur Barseghyan",
    author_email="artur.barseghyan@gmail.com",
    url="https://github.com/barseghyanartur/faker-file/",
    package_dir={"": "src"},
    packages=find_packages(where="./src"),
    license="MIT",
    install_requires=install_requires,
    tests_require=tests_require,
    dependency_links=dependency_links,
    include_package_data=True,
)



import os
import os.path as op

from faker_file_admin import app
from faker_file_admin.data import build_sample_db

# Build a sample db on the fly, if one does not exist yet.
app_dir = op.join(op.realpath(os.path.dirname(__file__)), "faker_file_admin")
database_path = op.join(app_dir, app.config["DATABASE_FILE"])
if not os.path.exists(database_path):
    build_sample_db()

if __name__ == "__main__":
    # Start app
    app.run(debug=True)
